@@ -197,7 +197,7 @@ def main():
 
     # option = input(' Digite uma opção:\n [1] para traduzir arquivos modificados desde o último commit,\n [2] para traduzir todo o projeto, ou\n [Enter] para sair: ')
 
-    @click.command()
+    @main.command()
     def diff():
         if workTree:
             PrYellow('\n The following files will be added or overwritten in target languages:')
@@ -232,8 +232,9 @@ def main():
             PrYellow('There are no changes since the last commit.')
         if cont != 'c': PrRed('\n\n Exiting...')
         time.sleep(1)
+        pass
 
-    @click.command()
+    @main.command()
     def all():
         global processed
         global greenFlag
